==> knative-model-6.3.1-sources.jar: io/fabric8/knative/eventing/contrib/github/v1alpha1/GitHubBindingListFluent.java <==
package io.fabric8.knative.eventing.contrib.github.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface GitHubBindingListFluent<A extends GitHubBindingListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,GitHubBinding item);
  public A setToItems(Integer index,GitHubBinding item);
  public A addToItems(io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubBinding... items);
  public A addAllToItems(Collection<GitHubBinding> items);
  public A removeFromItems(io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubBinding... items);
  public A removeAllFromItems(Collection<GitHubBinding> items);
  public A removeMatchingFromItems(Predicate<GitHubBindingBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<GitHubBinding> getItems();
  public List<GitHubBinding> buildItems();
  public GitHubBinding buildItem(Integer index);
  public GitHubBinding buildFirstItem();
  public GitHubBinding buildLastItem();
  public GitHubBinding buildMatchingItem(Predicate<GitHubBindingBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<GitHubBindingBuilder> predicate);
  public A withItems(List<GitHubBinding> items);
  public A withItems(io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubBinding... items);
  public Boolean hasItems();
  public GitHubBindingListFluent.ItemsNested<A> addNewItem();
  public GitHubBindingListFluent.ItemsNested<A> addNewItemLike(GitHubBinding item);
  public GitHubBindingListFluent.ItemsNested<A> setNewItemLike(Integer index,GitHubBinding item);
  public GitHubBindingListFluent.ItemsNested<A> editItem(Integer index);
  public GitHubBindingListFluent.ItemsNested<A> editFirstItem();
  public GitHubBindingListFluent.ItemsNested<A> editLastItem();
  public GitHubBindingListFluent.ItemsNested<A> editMatchingItem(Predicate<GitHubBindingBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,GitHubBindingFluent<GitHubBindingListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/eventing/contrib/github/v1alpha1/GitHubBindingListFluent.java <==
package io.fabric8.knative.eventing.contrib.github.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface GitHubBindingListFluent<A extends GitHubBindingListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,GitHubBinding item);
  public A setToItems(int index,GitHubBinding item);
  public A addToItems(io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubBinding... items);
  public A addAllToItems(Collection<GitHubBinding> items);
  public A removeFromItems(io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubBinding... items);
  public A removeAllFromItems(Collection<GitHubBinding> items);
  public A removeMatchingFromItems(Predicate<GitHubBindingBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<GitHubBinding> getItems();
  public List<GitHubBinding> buildItems();
  public GitHubBinding buildItem(int index);
  public GitHubBinding buildFirstItem();
  public GitHubBinding buildLastItem();
  public GitHubBinding buildMatchingItem(Predicate<GitHubBindingBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<GitHubBindingBuilder> predicate);
  public A withItems(List<GitHubBinding> items);
  public A withItems(io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubBinding... items);
  public Boolean hasItems();
  public GitHubBindingListFluent.ItemsNested<A> addNewItem();
  public GitHubBindingListFluent.ItemsNested<A> addNewItemLike(GitHubBinding item);
  public GitHubBindingListFluent.ItemsNested<A> setNewItemLike(int index,GitHubBinding item);
  public GitHubBindingListFluent.ItemsNested<A> editItem(int index);
  public GitHubBindingListFluent.ItemsNested<A> editFirstItem();
  public GitHubBindingListFluent.ItemsNested<A> editLastItem();
  public GitHubBindingListFluent.ItemsNested<A> editMatchingItem(Predicate<GitHubBindingBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,GitHubBindingFluent<GitHubBindingListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
